==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/request/AccessReviewScheduleDefinitionRequest.java <==
package odata.msgraph.client.beta.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ActionRequestNoReturn;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.util.Map;

import odata.msgraph.client.beta.entity.AccessReviewScheduleDefinition;
import odata.msgraph.client.beta.entity.collection.request.AccessReviewInstanceCollectionRequest;
import odata.msgraph.client.beta.schema.SchemaInfo;

@JsonIgnoreType
public class AccessReviewScheduleDefinitionRequest extends EntityRequest<AccessReviewScheduleDefinition> {

    public AccessReviewScheduleDefinitionRequest(ContextPath contextPath) {
        super(AccessReviewScheduleDefinition.class, contextPath, SchemaInfo.INSTANCE);
    }

    public AccessReviewInstanceCollectionRequest instances() {
        return new AccessReviewInstanceCollectionRequest(
                        contextPath.addSegment("instances"));
    }

    public AccessReviewInstanceRequest instances(String id) {
        return new AccessReviewInstanceRequest(contextPath.addSegment("instances").addKeys(new NameValue(id.toString())));
    }

    @Action(name = "stop")
    @JsonIgnore
    public ActionRequestNoReturn stop() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return new ActionRequestNoReturn(this.contextPath.addActionOrFunctionSegment("microsoft.graph.stop"), _parameters);
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/entity/request/AccessReviewScheduleDefinitionRequest.java <==
package odata.msgraph.client.beta.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ActionRequestNoReturn;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import odata.msgraph.client.beta.entity.AccessReviewScheduleDefinition;
import odata.msgraph.client.beta.entity.collection.request.AccessReviewInstanceCollectionRequest;

@JsonIgnoreType
public class AccessReviewScheduleDefinitionRequest extends EntityRequest<AccessReviewScheduleDefinition> {

    public AccessReviewScheduleDefinitionRequest(ContextPath contextPath, Optional<Object> value) {
        super(AccessReviewScheduleDefinition.class, contextPath, value, false);
    }

    public AccessReviewInstanceRequest instances(String id) {
        return new AccessReviewInstanceRequest(contextPath.addSegment("instances").addKeys(new NameValue(id, String.class)), Optional.empty());
    }

    public AccessReviewInstanceCollectionRequest instances() {
        return new AccessReviewInstanceCollectionRequest(
                        contextPath.addSegment("instances"), Optional.empty());
    }

    @Action(name = "stop")
    @JsonIgnore
    public ActionRequestNoReturn stop() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return new ActionRequestNoReturn(this.contextPath.addActionOrFunctionSegment("microsoft.graph.stop"), _parameters);
    }

}
